@@ -154,6 +154,12 @@ class TestFrFr(_SimpleAutomotiveTestMixin):
     license_plate_pattern: Pattern = re.compile(r"\d{3}-[A-Z]{3}-\d{2}|[A-Z]{2}-\d{3}-[A-Z]{2}")
 
 
+class TestItIt(_SimpleAutomotiveTestMixin):
+    """Test it_IT automotive provider methods"""
+
+    license_plate_pattern: Pattern = re.compile(r"[A-Z]{2}\d{3}[A-Z]{2}")
+
+
 class TestNoNo(_SimpleAutomotiveTestMixin):
     """Test no_NO automotive provider methods"""
 
@@ -274,3 +280,9 @@ class TestNlNl(_SimpleAutomotiveTestMixin):
             plate = faker.license_plate_motorbike()
             assert isinstance(plate, str)
             assert self.license_plate_motorbike_pattern.match(plate)
+
+
+class TestArBh(_SimpleAutomotiveTestMixin):
+    """Test ar_BH automotive provider methods"""
+
+    license_plate_pattern: Pattern = re.compile(r"\d{6}")
